App

Struct App 

pub struct App {
Show 87 fields pub theme: Theme, pub envelopes: Vec<Envelope>, pub all_envelopes: Vec<Envelope>, pub mailbox_view: MailboxView, pub labels: Vec<Label>, pub screen: Screen, pub mail_list_mode: MailListMode, pub selected_index: usize, pub scroll_offset: usize, pub active_pane: ActivePane, pub should_quit: bool, pub layout_mode: LayoutMode, pub search_bar: SearchBar, pub search_page: SearchPageState, pub command_palette: CommandPalette, pub body_view_state: BodyViewState, pub viewing_envelope: Option<Envelope>, pub viewed_thread: Option<Thread>, pub viewed_thread_messages: Vec<Envelope>, pub thread_selected_index: usize, pub message_scroll_offset: u16, pub last_sync_status: Option<String>, pub visible_height: usize, pub body_cache: HashMap<MessageId, MessageBody>, pub queued_body_fetches: Vec<MessageId>, pub in_flight_body_requests: HashSet<MessageId>, pub pending_thread_fetch: Option<ThreadId>, pub in_flight_thread_fetch: Option<ThreadId>, pub pending_search: Option<(String, SearchMode)>, pub search_active: bool, pub pending_rule_detail: Option<String>, pub pending_rule_history: Option<String>, pub pending_rule_dry_run: Option<String>, pub pending_rule_delete: Option<String>, pub pending_rule_upsert: Option<Value>, pub pending_rule_form_load: Option<String>, pub pending_rule_form_save: bool, pub pending_bug_report: bool, pub pending_log_open: bool, pub pending_diagnostics_details: Option<DiagnosticsPaneKind>, pub pending_account_save: Option<AccountConfigData>, pub pending_account_test: Option<AccountConfigData>, pub pending_account_authorize: Option<(AccountConfigData, bool)>, pub pending_account_set_default: Option<String>, pub sidebar_selected: usize, pub sidebar_section: SidebarSection, pub help_modal_open: bool, pub help_scroll_offset: u16, pub saved_searches: Vec<SavedSearch>, pub subscriptions_page: SubscriptionsPageState, pub rules_page: RulesPageState, pub diagnostics_page: DiagnosticsPageState, pub accounts_page: AccountsPageState, pub active_label: Option<LabelId>, pub pending_label_fetch: Option<LabelId>, pub pending_active_label: Option<LabelId>, pub pending_labels_refresh: bool, pub pending_all_envelopes_refresh: bool, pub pending_subscriptions_refresh: bool, pub pending_status_refresh: bool, pub desired_system_mailbox: Option<String>, pub status_message: Option<String>, pub pending_mutation_count: usize, pub pending_mutation_status: Option<String>, pub pending_mutation_queue: Vec<(Request, MutationEffect)>, pub pending_compose: Option<ComposeAction>, pub pending_send_confirm: Option<PendingSend>, pub pending_bulk_confirm: Option<PendingBulkConfirm>, pub error_modal: Option<ErrorModalState>, pub pending_unsubscribe_confirm: Option<PendingUnsubscribeConfirm>, pub pending_unsubscribe_action: Option<PendingUnsubscribeAction>, pub reader_mode: bool, pub signature_expanded: bool, pub label_picker: LabelPicker, pub compose_picker: ComposePicker, pub attachment_panel: AttachmentPanelState, pub snooze_panel: SnoozePanelState, pub pending_attachment_action: Option<PendingAttachmentAction>, pub selected_set: HashSet<MessageId>, pub visual_mode: bool, pub visual_anchor: Option<usize>, pub pending_export_thread: Option<ThreadId>, pub snooze_config: SnoozeConfig, pub sidebar_system_expanded: bool, pub sidebar_user_expanded: bool, pub sidebar_saved_searches_expanded: bool, pub url_modal: Option<UrlModalState>, /* private fields */
}

Fields

theme: Themeenvelopes: Vec<Envelope>all_envelopes: Vec<Envelope>mailbox_view: MailboxViewlabels: Vec<Label>screen: Screenmail_list_mode: MailListModeselected_index: usizescroll_offset: usizeactive_pane: ActivePaneshould_quit: boollayout_mode: LayoutModesearch_bar: SearchBarsearch_page: SearchPageStatecommand_palette: CommandPalettebody_view_state: BodyViewStateviewing_envelope: Option<Envelope>viewed_thread: Option<Thread>viewed_thread_messages: Vec<Envelope>thread_selected_index: usizemessage_scroll_offset: u16last_sync_status: Option<String>visible_height: usizebody_cache: HashMap<MessageId, MessageBody>queued_body_fetches: Vec<MessageId>in_flight_body_requests: HashSet<MessageId>pending_thread_fetch: Option<ThreadId>in_flight_thread_fetch: Option<ThreadId>pending_search: Option<(String, SearchMode)>search_active: boolpending_rule_detail: Option<String>pending_rule_history: Option<String>pending_rule_dry_run: Option<String>pending_rule_delete: Option<String>pending_rule_upsert: Option<Value>pending_rule_form_load: Option<String>pending_rule_form_save: boolpending_bug_report: boolpending_log_open: boolpending_diagnostics_details: Option<DiagnosticsPaneKind>pending_account_save: Option<AccountConfigData>pending_account_test: Option<AccountConfigData>pending_account_authorize: Option<(AccountConfigData, bool)>pending_account_set_default: Option<String>sidebar_selected: usizesidebar_section: SidebarSectionhelp_modal_open: boolhelp_scroll_offset: u16saved_searches: Vec<SavedSearch>subscriptions_page: SubscriptionsPageStaterules_page: RulesPageStatediagnostics_page: DiagnosticsPageStateaccounts_page: AccountsPageStateactive_label: Option<LabelId>pending_label_fetch: Option<LabelId>pending_active_label: Option<LabelId>pending_labels_refresh: boolpending_all_envelopes_refresh: boolpending_subscriptions_refresh: boolpending_status_refresh: booldesired_system_mailbox: Option<String>status_message: Option<String>pending_mutation_count: usizepending_mutation_status: Option<String>pending_mutation_queue: Vec<(Request, MutationEffect)>pending_compose: Option<ComposeAction>pending_send_confirm: Option<PendingSend>pending_bulk_confirm: Option<PendingBulkConfirm>error_modal: Option<ErrorModalState>pending_unsubscribe_confirm: Option<PendingUnsubscribeConfirm>pending_unsubscribe_action: Option<PendingUnsubscribeAction>reader_mode: boolsignature_expanded: boollabel_picker: LabelPickercompose_picker: ComposePickerattachment_panel: AttachmentPanelStatesnooze_panel: SnoozePanelStatepending_attachment_action: Option<PendingAttachmentAction>selected_set: HashSet<MessageId>visual_mode: boolvisual_anchor: Option<usize>pending_export_thread: Option<ThreadId>snooze_config: SnoozeConfigsidebar_system_expanded: boolsidebar_user_expanded: boolsidebar_saved_searches_expanded: boolurl_modal: Option<UrlModalState>

Implementations

Source

impl App

pub fn tick(&mut self)

pub fn apply(&mut self, action: Action)

Source

impl App

pub fn draw(&mut self, frame: &mut Frame<'_>)

Source

impl App

pub fn handle_key(&mut self, key: KeyEvent) -> Option<Action>

Source

impl App

pub fn new() -> Self

pub fn from_config(config: &MxrConfig) -> Self

pub fn from_render_config(render: &RenderConfig) -> Self

pub fn selected_envelope(&self) -> Option<&Envelope>

pub fn mail_list_rows(&self) -> Vec<MailListRow>

pub fn search_mail_list_rows(&self) -> Vec<MailListRow>

pub fn selected_mail_row(&self) -> Option<MailListRow>

pub fn selected_subscription_entry(&self) -> Option<&SubscriptionEntry>

pub fn focused_thread_envelope(&self) -> Option<&Envelope>

pub fn sidebar_items(&self) -> Vec<SidebarItem>

pub fn selected_sidebar_item(&self) -> Option<SidebarItem>

pub fn selected_search_envelope(&self) -> Option<&Envelope>

pub fn selected_rule(&self) -> Option<&Value>

pub fn selected_account(&self) -> Option<&AccountSummaryData>

pub fn enter_account_setup_onboarding(&mut self)

pub async fn load(&mut self, client: &mut Client) -> Result<(), MxrError>

pub fn apply_status_snapshot( &mut self, uptime_secs: u64, daemon_pid: Option<u32>, accounts: Vec<String>, total_messages: u32, sync_statuses: Vec<AccountSyncStatus>, )

pub fn input_pending(&self) -> bool

pub fn ordered_visible_labels(&self) -> Vec<&Label>

pub fn visible_label_count(&self) -> usize

Number of visible (non-hidden) labels.

pub fn visible_labels(&self) -> Vec<&Label>

Get the visible (filtered) labels.

pub fn mail_list_title(&self) -> String

Compute the mail list title based on active filter/search.

pub fn status_bar_state(&self) -> StatusBarState

pub fn resolve_desired_system_mailbox(&mut self)

pub fn queue_body_window(&mut self)

Queue body prefetch for messages around the current cursor position. Only fetches bodies not already in cache.

pub fn next_background_timeout(&self, fallback: Duration) -> Duration

pub fn resolve_body_success(&mut self, body: MessageBody)

pub fn resolve_body_fetch_error( &mut self, message_id: &MessageId, message: String, )

pub fn current_viewing_body(&self) -> Option<&MessageBody>

pub fn selected_attachment(&self) -> Option<&AttachmentMeta>

pub fn open_attachment_panel(&mut self)

pub fn open_url_modal(&mut self)

pub fn close_attachment_panel(&mut self)

pub fn queue_attachment_action(&mut self, operation: AttachmentOperation)

pub fn resolve_attachment_file(&mut self, file: &AttachmentFile)

pub fn apply_local_label_refs( &mut self, message_ids: &[MessageId], add: &[String], remove: &[String], )

pub fn apply_local_flags(&mut self, message_id: &MessageId, flags: MessageFlags)

pub fn apply_local_flags_many(&mut self, updates: &[(MessageId, MessageFlags)])

pub fn finish_pending_mutation(&mut self)

pub fn show_mutation_failure(&mut self, error: &MxrError)

pub fn refresh_mailbox_after_mutation_failure(&mut self)

pub fn resolve_thread_success( &mut self, thread: Thread, messages: Vec<Envelope>, )

pub fn resolve_thread_fetch_error(&mut self, thread_id: &ThreadId)

pub fn set_subscriptions(&mut self, subscriptions: Vec<SubscriptionSummary>)